==> haskell-logict-0.6.0.2-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-logict.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: logict
version: 0.6.0.2
id: logict-0.6.0.2-bTigcTuAfUFUMwCRYsf8L
key: logict-0.6.0.2-bTigcTuAfUFUMwCRYsf8L
license: BSD-3-Clause
copyright: Copyright (c) 2007-2014, Dan Doel,
           Copyright (c) 2011-2013, Edward Kmett,
           Copyright (c) 2014, Roman Cheplyaka
maintainer: dan.doel@gmail.com
author: Dan Doel
homepage: http://code.haskell.org/~dolio/
synopsis: A backtracking logic-programming monad.
description:
    A continuation-based, backtracking, logic programming monad.
    An adaptation of the two-continuation implementation found
    in the paper "Backtracking, Interleaving, and Terminating
    Monad Transformers" available here:
    <http://okmij.org/ftp/papers/LogicT.pdf>
category: Control
abi: 93a38d7204a51c002db7c04ebda479ff
exposed: True
exposed-modules:
    Control.Monad.Logic Control.Monad.Logic.Class
import-dirs: /usr/lib/ghc-8.4.3/site-local/logict-0.6.0.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/logict-0.6.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/logict-0.6.0.2
hs-libraries: HSlogict-0.6.0.2-bTigcTuAfUFUMwCRYsf8L
depends:
    base-4.11.1.0 mtl-2.2.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
haddock-interfaces: /usr/share/doc/haskell-logict/html/logict.haddock
haddock-html: /usr/share/doc/haskell-logict/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-logict-0.6.0.2-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-logict.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: logict
version: 0.6.0.2
id: logict-0.6.0.2-7kzxfuFd7UY9IiY3jFziUO
key: logict-0.6.0.2-7kzxfuFd7UY9IiY3jFziUO
license: BSD-3-Clause
copyright: Copyright (c) 2007-2014, Dan Doel,
           Copyright (c) 2011-2013, Edward Kmett,
           Copyright (c) 2014, Roman Cheplyaka
maintainer: dan.doel@gmail.com
author: Dan Doel
homepage: http://code.haskell.org/~dolio/
synopsis: A backtracking logic-programming monad.
description:
    A continuation-based, backtracking, logic programming monad.
    An adaptation of the two-continuation implementation found
    in the paper "Backtracking, Interleaving, and Terminating
    Monad Transformers" available here:
    <http://okmij.org/ftp/papers/LogicT.pdf>
category: Control
abi: def03c370613cef96ab3f7c5bd862984
exposed: True
exposed-modules:
    Control.Monad.Logic Control.Monad.Logic.Class
import-dirs: /usr/lib/ghc-8.6.1/site-local/logict-0.6.0.2
library-dirs: /usr/lib/ghc-8.6.1/site-local/logict-0.6.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/logict-0.6.0.2
hs-libraries: HSlogict-0.6.0.2-7kzxfuFd7UY9IiY3jFziUO
depends:
    base-4.12.0.0 mtl-2.2.2
haddock-interfaces: /usr/share/doc/haskell-logict/html/logict.haddock
haddock-html: /usr/share/doc/haskell-logict/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
